                 PLX 8619 SERDES Hspice Simulation Deck

* TSMC 90nm channel simulation   {PLX 8619}

*************************
* PARAMETER AND OPTIONS *
*************************

.option nowarn post_version=9007 post

*******************************
* SIMULATION CONDITIONS (PVT) *
*******************************
.protect
.lib './process_corner.lib' tt
.unprotect

vvdd vdd 0  dc 1.0
vgnd gnd 0  dc 0

.temp 40 

*******************************************************
* TOP LEVEL CIRCUIT TOPOLOGY (TX, RX, PACKAGE, BOARD) *
*******************************************************
.include txrx_sparam_system.spi

***********************************************
* Bias Tx/Rx Control Inputs                   *
* For a complete description of control bits, *
* refer to the README documentation.          *
***********************************************

* TX Only Control Bits 

vdrv_lvl4  drv_lvl[4]  0 1     $ 3dB default setting: 10'h = 10000'b <----
vdrv_lvl3  drv_lvl[3]  0 0     $ 6dB default setting: 0E'h = 01110'b
vdrv_lvl2  drv_lvl[2]  0 0     
vdrv_lvl1  drv_lvl[1]  0 0     
vdrv_lvl0  drv_lvl[0]  0 0

vemp_post4 emp_post[4] 0 0     $ 3dB default setting: 0D'h = 01101'b <----
vemp_post3 emp_post[3] 0 1     $ 6dB default setting: 15'h = 10101'b
vemp_post2 emp_post[2] 0 1     
vemp_post1 emp_post[1] 0 0     
vemp_post0 emp_post[0] 0 1

* RX Only Control Bits 

vrx_eq3       rx_eq[3]     0 0    $ 0000 - Medium RX Equalization
vrx_eq2       rx_eq[2]     0 0    $ (Default Setting)
vrx_eq1       rx_eq[1]     0 0
vrx_eq0       rx_eq[0]     0 0

* The following control bits are best left alone. Changing them 
* will results in unpredictable behavior.

vrx_term      rx_term      0 0   $ Enable 50 ohm internal termination
vrx_cm        rx_cm        0 1   $ Enable RX internal common mode
vrx_ac_couple rx_ac_couple 0 1   $ Disable RX internal AC coupling cap

* TX-RX Common Control Bits 

vband         band         0 0   $ 0 sets GEN-II speed

vres_code3 res_code[3] 0 dc 0    $0111 = TT Corner <--------
vres_code2 res_code[2] 0 dc 1    $1100 = SS Corner 
vres_code1 res_code[1] 0 dc 1    $0001 = FF Corner 
vres_code0 res_code[0] 0 dc 1

*********************************************************
* Input Stimulus                                        *
* The following is a sample bit stream pattern.         *
* User can change the input stimulus per specification  *
*********************************************************
.param par_freq=5.0e9 

vdata_pos txp_in gnd dc=0 PWL 0 -200e-3 '320e-3/par_freq' 200e-3 '2/par_freq' 200e-3
+ '2/par_freq+320e-3/par_freq' -200e-3 '7/par_freq' -200e-3 '7/par_freq+320e-3/par_freq'
+ 200e-3 '8/par_freq' 200e-3 '8/par_freq+320e-3/par_freq' -200e-3 '9/par_freq' -200e-3
+ '9/par_freq+320e-3/par_freq' 200e-3 '10/par_freq' 200e-3 '10/par_freq+320e-3/par_freq'
+ -200e-3 '12/par_freq' -200e-3 '12/par_freq+320e-3/par_freq' 200e-3 '17/par_freq' 200e-3
+ '17/par_freq+320e-3/par_freq' -200e-3 '18/par_freq' -200e-3 '18/par_freq+320e-3/par_freq'
+ 200e-3 '19/par_freq' 200e-3 '19/par_freq+320e-3/par_freq' -200e-3 '19.9999999/par_freq'
+ -200e-3 R=0 TD='1/par_freq' r

************
* Analysis *
************
.param ui='1/par_freq'
.tran 5ps '140*ui' 

**************
* Measurement*
**************

ediff6 diff_rx6 0 poly(1) rxp6 rxn6 0 1

.include eye_rxpin6_diff.inc

******************
* Alter Examples *
******************

*.alter  $ Run SS Corner
*.lib './process_corner.lib' ss
*vres_code3 res_code[3] 0 dc 1    $0111 = TT Corner 
*vres_code2 res_code[2] 0 dc 1    $1100 = SS Corner <--------
*vres_code1 res_code[1] 0 dc 0    $0001 = FF Corner 
*vres_code0 res_code[0] 0 dc 0

*.alter  $ Run FF Corner
*.lib './process_corner.lib' ff
*vres_code3 res_code[3] 0 dc 0    $0111 = TT Corner 
*vres_code2 res_code[2] 0 dc 0    $1100 = SS Corner 
*vres_code1 res_code[1] 0 dc 0    $0001 = FF Corner <--------
*vres_code0 res_code[0] 0 dc 1

.end
